@@ -5,7 +5,7 @@ class Vorwerk(Vendor):
     name = "vorwerk"
     endpoint = "https://beehive.ksecosys.com/"
     passwordless_endpoint = "https://mykobold.eu.auth0.com/passwordless/start"
-    token_endpoint = "https://mykobold.eu.auth0.com/oauth/token"
-    scope = ["openid", "email", "profile", "read:current_user"]
+    token_endpoint = "https://mykobold.eu.auth0.com/oauth/token"  # nosec
+    scope = ["openid", "email", "profile", "read:current_user", "offline_access"]
     audience = "https://mykobold.eu.auth0.com/userinfo"
     source = "vorwerk_auth0"
